@@ -10,12 +10,14 @@ if [ ! -f "$testf" ]; then
 	exit 1
 fi
 
-export HOME="$pwd/debian/test-home"
-export LC_ALL='C.UTF-8'
-export LANGUAGE='C'
-export PYTHON3="$(py3versions -d)"
+HOME="$pwd/debian/test-home"
+LC_ALL='C.UTF-8'
+LANGUAGE='C'
+PYTHON3="$(py3versions -d)"
+export HOME LC_ALL LANGUAGE PYTHON3
 
 dir="$(mktemp -d -t gitless-test.XXXXXX)"
+# shellcheck disable=SC2064
 trap "rm -rf -- '$dir'" EXIT HUP INT QUIT TERM
 
 echo "Using directory $dir"
