@@ -24,6 +24,7 @@ export PATH="$gitless_dir:$PATH"
 # Okay, do we need to symlink it, too?
 if [ ! -f "$GITLESS" ] && [ -f "$GITLESS.py" ]; then
 	ln -s -- "$GITLESS.py" "$GITLESS"
+	# shellcheck disable=SC2064
 	trap "rm -f -- '$GITLESS'" EXIT HUP INT QUIT TERM
 fi
 
@@ -33,10 +34,11 @@ if [ ! -f "$GITLESS" ] || [ ! -x "$GITLESS" ]; then
 	exit 1
 fi
 
-export LC_ALL='C.UTF-8'
-export LANGUAGE='C'
-export PYBUILD_NAME='gitless'
-export PYTHON3="$(py3versions -d)"
+LC_ALL='C.UTF-8'
+LANGUAGE='C'
+PYBUILD_NAME='gitless'
+PYTHON3="$(py3versions -d)"
+export LC_ALL LANGUAGE PYBUILD_NAME PYTHON3
 
 pyver="$(py3versions -d -v)"
 
